ctt-intel-texture-compressor 0.1.0

Vendored Intel ISPC texture compressor bindings, based on intel_tex_2
docs.rs failed to build ctt-intel-texture-compressor-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: ctt-intel-texture-compressor-0.4.0

ctt-intel-texture-compressor

Vendored Intel ISPC texture compressor bindings for the ctt workspace.

Based on intel-tex-rs-2 by Traverse Research & Graham Wihlidal, which wraps Intel's ISPCTextureCompressor.

Supported formats

  • BC1, BC3, BC4, BC5, BC6H, BC7
  • ETC1
  • ASTC

Build requirements

License

The Rust bindings are licensed under MIT OR Apache-2.0 (see LICENSE-MIT and LICENSE-APACHE).

The ISPC/C++ source code in ispc/ is licensed under MIT by Intel Corporation (see LICENSE-MIT-INTEL).